# Upload a new version of an existing entry to the OSSR 

 - Uses the GitLab CI to upload a **new version** of the current project to the ESCAPE-OSSR (The ESCAPE2020 Zenodo 
 community).
     - Note that the CI will be only triggered with the creation of a new release.
 - The `codemeta.json` file - compulsory if you want to run this code - will be also added to the Zenodo entry as 
 a separate file.
 - The `eossr-check-connection-zenodo` stage will create a fist dummy upload (that will be always erased), to check
 that the released code will be successfully uploaded. 
 
**NOTE**.
You should have saved the `deposit_id` of your project as a GitLab environment variable before the CI runs this stage.

To do so:
1. Go to https://zenodo.org/deposit,
2. Click onto your just uploaded project,
3. From your browser search bar, **just** copy the number (your `deposit id`) that it is included in the https direction.
   - ex: `https://zenodo.org/record/3884963` --> just copy `3884963`.
4. Save it as a new environment variable in your GitLab project. 
    * Go to your GitLab project. 
    * Click on `Settings` --> `CI/CD` --> `Variables` --> `Add variable` 
    * `KEY`=`$ZENODO_PROJECT_ID` and fill the value with the deposit id.
    * For Sandbox Zenodo use `KEY` = `SANDBOX_ZENODO_PROJECT_ID`


### Upload to Zenodo
```yaml
stages:
 - deploy 

deploy_zenodo:
  stage: deploy
  image: gitlab-registry.in2p3.fr/escape2020/wp3/eossr:latest
  before_script:
    - eossr-check-connection-zenodo --token $ZENODO_TOKEN --sandbox False -p $CI_PROJECT_DIR
  script:
    - mkdir -p build
    - parse_last_release_git.sh $CI_PROJECT_NAME $CI_PROJECT_URL
    - if [[ -f ./codemeta.json ]]; then cp ./codemeta.json ./build; fi
    - ls ./build

    - eossr-upload-new-version-deposit -t $ZENODO_TOKEN -s False -i ./build -id $ZENODO_PROJECT_ID
  only:
    - tags

``` 


### Upload to Sandbox Zenodo
```yaml
stages:
 - deploy 

deploy_zenodo:
  stage: deploy
  image: gitlab-registry.in2p3.fr/escape2020/wp3/eossr:latest
  before_script:
    - eossr-check-connection-zenodo --token $SANDBOX_ZENODO_TOKEN --sandbox True -p $CI_PROJECT_DIR
  script:
    - mkdir -p build
    - parse_last_release_git.sh $CI_PROJECT_NAME $CI_PROJECT_URL
    - if [[ -f ./codemeta.json ]]; then cp ./codemeta.json ./build; fi
    - ls ./build

    - eossr-upload-new-version-deposit -t $SANDBOX_ZENODO_TOKEN -s True -i ./build -id $SANDBOX_ZENODO_PROJECT_ID
  only:
    - tags

``` 
